<!-- This file is compiled from plain-esbuild/plain/esbuild/README.md. Do not edit this file directly. -->

# plain.esbuild

Build JavaScript files with esbuild.

## gitignore

```
**/assets/**/*.esbuilt.*
```
